require 'net/ssh/errors'
require 'net/ssh/known_hosts'
require 'net/ssh/verifiers/secure'


module Net #:nodoc:
  module SSH #:nodoc:
    module Verifiers #:nodoc:
      #
      # This is similar to Net::SSH::Verifiers::Strict, but does not save the
      # host key if it does not already exist in the known hosts file(s),
      # making it ideal for repeat provisions of varied VMs that re-use IP
      # addresses.
      #
      # It still goes through normal verification for those keys that do exist
      # in the known hosts files, however.
      #
      #--
      # XXX the inheritance here is correct. Strict inherits from secure, but saves
      #     instead. We're just like strict but we don't save.
      #++
      class NoSaveStrict < Secure
        #
        # Verify the connection. See NoSaveStrict.
        #
        def verify(arguments)
          super
        rescue HostKeyUnknown
          return true
        end
      end
    end
  end
end
